---
slug: /error-code-8000-8999
---

# 8000 ~ 8999

The error codes in this range indicate serious errors. When a client receives an 8xxx error, it must close the SQL connection.

## ERROR 8001 (08004) : Server is initializing

* seekdb error code: 8001

* Error reason: An RPC request is received during the startup of seekdb.

* Solution: Wait for seekdb to restart.

## ERROR 8002 (08004) : Server is stopping

* seekdb error code: 8002

* Error reason: An RPC request is received during the shutdown of seekdb.

* Solution: Wait for seekdb to exit normally. Or execute `kill -9` to forcibly terminate the observer process.

## ERROR 8003 (08004) : Packet checksum error

* seekdb error code: 8003

* Error reason: The `checksum` check of the RPC packet fails. This is usually due to version compatibility issues.

* Solution: Contact technical support for troubleshooting.